"""This module contains logic for computationality mutating (row/col)s."""


def _combine_l(tile_list):
    """
    Combine like pairs in a list in order (reverse, left).

    - parameters:
        - tile_list: {}
    -returns: {tuple} a tuple with:
                        [0]: the new row / column
                        [1]: the score from the combination
    """
    score = 0
    # if the list contains zero or one item(s), return itself
    if len(tile_list) is 0 or len(tile_list) is 1:
        return (tile_list, 0)
    # make a new list for the combined pairs
    combined_tiles = []
    i = 0
    while i < len(tile_list):
        # get the current item
        current = tile_list[i]
        # if we're at the last index, add it to the list and exit the loop
        if i is len(tile_list) - 1:
            combined_tiles.append(current)
            i += 1
            continue
        # get the next item
        next_item = tile_list[i + 1]
        # if its the same as the current value then add them and push that
        # value to the list. increment the iterator to skip the next
        # value in the loop
        if current is next_item:
            combined_tiles.append(current + 1)
            score += 2**(current + 1)
            i += 1
        # append the item to the list and return
        else:
            combined_tiles.append(current)
        i += 1
    # return the new list of items
    return (combined_tiles, score)


def _combine_r(tile_list):
    """
    Combine like pairs in a list in order (normal - right).

    - parameters:
        - tile_list: {}
    -returns: {tuple} a tuple with:
                        [0]: the new row / column
                        [1]: the score from the combination
    """
    score = 0
    # if the list contains zero or one item(s), return itself
    if len(tile_list) is 0 or len(tile_list) is 1:
        return (tile_list, 0)
    # make a new list for the combined pairs
    combined_tiles = []
    i = len(tile_list) - 1
    while i >= 0:
        # get the current item
        current = tile_list[i]
        # if we're at the last index, add it to the list and exit the loop
        if i is 0:
            combined_tiles.insert(0, current)
            i -= 1
            continue
        # get the next item
        next_item = tile_list[i - 1]
        # if its the same as the current value then add them and push that
        # value to the list. increment the iterator to skip the next
        # value in the loop
        if current is next_item:
            combined_tiles.insert(0, current + 1)
            score += 2**(current + 1)
            i -= 1
        # append the item to the list and return
        else:
            combined_tiles.insert(0, current)
        i -= 1
    # return the new list of items
    return (combined_tiles, score)


def combine_left(row_col):
    """
    Return a list with the tiles in the given list shifted to the left.

    - parameters:
        - row_col: {byte[]} the tiles to combine
    - returns: {tuple} a tuple with:
                        [0]: an array of the tiles shifted to the left
                        [1]: the score from the move
    """
    no_zero = list(filter((0).__ne__, row_col))
    combined = _combine_l(list(no_zero))
    for index in range(len(combined[0]), 4):
        combined[0].append(0)
    return combined


def combine_right(row_col):
    """
    Return a list with the tiles in the given list shifted to the right.

    - parameters:
        - row_col: {byte[]} the tiles to combine
    - returns: {tuple} a tuple with:
                        [0]: an array of the tiles shifted to the left
                        [1]: the score from the move
    """
    no_zero = list(filter((0).__ne__, row_col))
    combined = _combine_r(no_zero)
    for index in range(len(combined[0]), 4):
        combined[0].insert(0, 0)
    return combined
