"""this module contains metadata about gamebords."""


class Constants:
    """This class contains constants for the game."""

    @classmethod
    def rows(cls):
        """Return the number of rows in a board."""
        return 4

    @classmethod
    def columns(cls):
        """Return the number of columns in a board."""
        return 4

    @classmethod
    def tiles(cls):
        """Return the number of tiles on a board."""
        return Constants.rows() * Constants.columns()

    @classmethod
    def tile_size(cls):
        """Return the size of a single tile in bits."""
        return 4

    @classmethod
    def board_size(cls):
        """Return the size of a board in bits."""
        return Constants.tiles() * Constants.tile_size()

    @classmethod
    def row_size(cls):
        """Return the size of a single row in bits."""
        return Constants.board_size() / Constants.rows()

    @classmethod
    def column_size(cls):
        """Return the size of a single column in bits."""
        return Constants.board_size() / Constants.columns()

    @classmethod
    def chance_of_four(cls):
        """Return the odds of randomly placing a 4 (out of 1)."""
        return 0.25

    # values for masking the board

    @classmethod
    def tile_mask(cls):
        """Return the hex value for masking tiles on the board."""
        return 0xf000000000000000

    @classmethod
    def tile_value_mask(cls):
        """Return the hex value for masking tiles from input ints."""
        return 0x000000000000000f

    @classmethod
    def row_mask(cls):
        """Return the mask for getting rows off the board."""
        return 0xffff000000000000

    @classmethod
    def column_mask(cls):
        """Return the mask for getting columns off the board."""
        return 0xf000f000f000f000

    # shift values

    @classmethod
    def column_shift(cls):
        """Return an array of the shift indecies for mutating columns."""
        return [48, 32, 16, 0]

    @classmethod
    def tile_shift(cls):
        """Return an array of the shift indexes for mutating tiles in a row."""
        return [12, 8, 4, 0]

    # values for masking numbers

    @classmethod
    def short_mask(cls):
        """Return the mask for getting shorts from ints."""
        return 0x000000000000ffff

    @classmethod
    def long_mask(cls):
        """Return the mask for getting longs from ints."""
        return 0xffffffffffffffff
