"""This module contains an interface for responding to events from the game."""


class GameBoardDelegate:
    """This interface delegate events from a 2048 game."""

    def did_move_up(self, did_score, move_matrix=None):
        """
        Respond to the board moving up.

        - parameters:
            - did_score: {boolean} a boolean indicating whether the user scored
            - move_matrix: {byte[rowsxcolumns]} the matrix of indecies
                                            indicating where tiles moved
        """
        pass

    def did_move_down(self, did_score, move_matrix=None):
        """
        Respond to the board moving down.

        - parameters:
            - did_score: {boolean} a boolean indicating whether the user scored
            - move_matrix: {byte[rowsxcolumns]} the matrix of indecies
                                            indicating where tiles moved
        """
        pass

    def did_move_left(self, did_score, move_matrix=None):
        """
        Respond to the board moving left.

        - parameters:
            - did_score: {boolean} a boolean indicating whether the user scored
            - move_matrix: {byte[rowsxcolumns]} the matrix of indecies
                                            indicating where tiles moved
        """
        pass

    def did_move_right(self, did_score, move_matrix=None):
        """
        Respond to the board moving right.

        - parameters:
            - did_score: {boolean} a boolean indicating whether the user scored
            - move_matrix: {byte[rowsxcolumns]} the matrix of indecies
                                            indicating where tiles moved
        """
        pass

    def did_place_new_tile(self, row, column, value):
        """
        Respond to a new tile being placed.

        - parameters:
            - row: {int} the row the tile was placed at
            - column: {int} the column the tile was placed at
            - value: {byte} the value that wale placed
        """
        pass

    def did_start_new_game(self):
        """Respond to the game being reset."""
        pass
